@@ -14,14 +14,32 @@ from bgameb.errors import StuffDefineError
 class BaseStuff(Base, ABC):
     """Base class for game stuff (like dices or cards)
     """
+    count: int = 1
+    # rules: List[str] = field(default_factory=list)
 
 
 @dataclass
-class RollerType(BaseStuff):
-    """Base class for define types of rollers or fliped objects
+class Rule(BaseStuff):
+    """Rule object
+    """
+    count: int = field(
+        default=1,
+        metadata=config(exclude=lambda x: True),
+        # init=False,
+        repr=False
+        )
+    text: Optional[str] = None
+
+    def __post_init__(self) -> None:
+        super().__post_init__()
+
+
+@dataclass
+class Dice(BaseStuff):
+    """Base class for define types of rolled or fliped objects
 
     Define name to identify later this object by unique name.
-    For example: 'six_side_dice'
+    For example: 'six_side'
 
     Sides attr define number of sides of roller. Default to 2.
     Sides can't be less than 2, because one-sided roller is
@@ -30,11 +48,17 @@ class RollerType(BaseStuff):
     .. code-block::
         :caption: Example:
 
-            dice = RollerType(name='coin', sides=2)
+            dice = Dice(name='coin', sides=2)
 
     Raises:
         StuffDefineError: number of sides less than 2
     """
+    _range: List[int] = field(
+        default_factory=list,
+        metadata=config(exclude=lambda x: True),
+        init=False,
+        repr=False
+        )
     sides: int = 2
 
     def __post_init__(self) -> None:
@@ -45,22 +69,6 @@ class RollerType(BaseStuff):
                         f'for {self.name}. Needed >= 2.',
                 logger=self.logger
                 )
-
-
-@dataclass
-class Roller(RollerType):
-    """Creare the roller (like dice or coin)
-    """
-    _range: List[int] = field(
-        default_factory=list,
-        metadata=config(exclude=lambda x: True),
-        init=False,
-        repr=False
-        )
-    count: int = 0
-
-    def __post_init__(self) -> None:
-        super().__post_init__()
         self._range = list(range(1, self.sides + 1))
 
     def roll(self) -> List[int]:
@@ -78,7 +86,7 @@ class Roller(RollerType):
 
 
 @dataclass
-class CardType(BaseStuff):
+class Card(BaseStuff):
     """Create the card
 
     Define name to identify later this object by unique name.
@@ -92,25 +100,7 @@ class CardType(BaseStuff):
     open: bool = False
     tapped: bool = False
     side: Optional[str] = None
-    count: int = 0
-
-    def __post_init__(self) -> None:
-        super().__post_init__()
-
-
-@dataclass
-class Card(CardType):
-    """Create the card
-    """
-    counter: Counter = field(
-        default_factory=Counter,
-        init=False,
-        )
-    count: int = field(
-        default=0,
-        metadata=config(exclude=lambda x: True),
-        repr=False
-        )
+    counter: Counter = field(default_factory=Counter)
 
     def __post_init__(self) -> None:
         super().__post_init__()
@@ -165,7 +155,8 @@ class Card(CardType):
 
 
 STUFF = {
-    'roller': RollerType,
-    'card': CardType,
-}
-STUFF_TYPES = Literal['roller', 'card']
+    'rule': Rule,
+    'dice': Dice,
+    'card': Card,
+    }
+STUFF_TYPES = Literal['rule', 'dice', 'card']
